Enum debug_sat::Proof
[−]
[src]
pub enum Proof {
True,
False,
Unknown,
Unexpected,
Error,
}Stores result of a proof.
Variants
TrueLocally correct and no contradiction so far. NB! This does not mean that the proof is correct. This required assigning a value to every variable.
FalseContradiction. There exists some assumption of consequence of assumptions which contradicts the conclusion of the tactic.
UnknownIt is unknown whether the tactic can be applied at this moment. Add more assumptions and try again, or try a different tactic.
UnexpectedA contradiction to the assumption of the tactic was found. This does not mean the proof is wrong, but that this particular tactic is the wrong strategy.
ErrorThis tactic can not be performed on this expression. Usually due to grammatical error.